@@ -786,6 +786,7 @@ pulse_connection_set_default_sink (PulseConnection *connection,
     pa_operation *op;
 
     g_return_val_if_fail (PULSE_IS_CONNECTION (connection), FALSE);
+    g_return_val_if_fail (name != NULL, FALSE);
 
     if (connection->priv->state != PULSE_CONNECTION_CONNECTED)
         return FALSE;
@@ -804,6 +805,7 @@ pulse_connection_set_default_source (PulseConnection *connection,
     pa_operation *op;
 
     g_return_val_if_fail (PULSE_IS_CONNECTION (connection), FALSE);
+    g_return_val_if_fail (name != NULL, FALSE);
 
     if (connection->priv->state != PULSE_CONNECTION_CONNECTED)
         return FALSE;
@@ -823,6 +825,8 @@ pulse_connection_set_card_profile (PulseConnection *connection,
     pa_operation *op;
 
     g_return_val_if_fail (PULSE_IS_CONNECTION (connection), FALSE);
+    g_return_val_if_fail (card != NULL, FALSE);
+    g_return_val_if_fail (profile != NULL, FALSE);
 
     if (connection->priv->state != PULSE_CONNECTION_CONNECTED)
         return FALSE;
@@ -863,6 +867,7 @@ pulse_connection_set_sink_volume (PulseConnection  *connection,
     pa_operation *op;
 
     g_return_val_if_fail (PULSE_IS_CONNECTION (connection), FALSE);
+    g_return_val_if_fail (volume != NULL, FALSE);
 
     if (connection->priv->state != PULSE_CONNECTION_CONNECTED)
         return FALSE;
@@ -883,6 +888,7 @@ pulse_connection_set_sink_port (PulseConnection *connection,
     pa_operation *op;
 
     g_return_val_if_fail (PULSE_IS_CONNECTION (connection), FALSE);
+    g_return_val_if_fail (port != NULL, FALSE);
 
     if (connection->priv->state != PULSE_CONNECTION_CONNECTED)
         return FALSE;
@@ -923,6 +929,7 @@ pulse_connection_set_sink_input_volume (PulseConnection  *connection,
     pa_operation *op;
 
     g_return_val_if_fail (PULSE_IS_CONNECTION (connection), FALSE);
+    g_return_val_if_fail (volume != NULL, FALSE);
 
     if (connection->priv->state != PULSE_CONNECTION_CONNECTED)
         return FALSE;
@@ -963,6 +970,7 @@ pulse_connection_set_source_volume (PulseConnection  *connection,
     pa_operation *op;
 
     g_return_val_if_fail (PULSE_IS_CONNECTION (connection), FALSE);
+    g_return_val_if_fail (volume != NULL, FALSE);
 
     if (connection->priv->state != PULSE_CONNECTION_CONNECTED)
         return FALSE;
@@ -983,6 +991,7 @@ pulse_connection_set_source_port (PulseConnection *connection,
     pa_operation *op;
 
     g_return_val_if_fail (PULSE_IS_CONNECTION (connection), FALSE);
+    g_return_val_if_fail (port != NULL, FALSE);
 
     if (connection->priv->state != PULSE_CONNECTION_CONNECTED)
         return FALSE;
@@ -1000,7 +1009,6 @@ pulse_connection_set_source_output_mute (PulseConnection *connection,
                                          guint32          index,
                                          gboolean         mute)
 {
-#if PA_CHECK_VERSION(1, 0, 0)
     pa_operation *op;
 
     g_return_val_if_fail (PULSE_IS_CONNECTION (connection), FALSE);
@@ -1014,9 +1022,6 @@ pulse_connection_set_source_output_mute (PulseConnection *connection,
                                             NULL, NULL);
 
     return process_pulse_operation (connection, op);
-#else
-    return FALSE;
-#endif
 }
 
 gboolean
@@ -1024,10 +1029,10 @@ pulse_connection_set_source_output_volume (PulseConnection  *connection,
                                            guint32           index,
                                            const pa_cvolume *volume)
 {
-#if PA_CHECK_VERSION(1, 0, 0)
     pa_operation *op;
 
     g_return_val_if_fail (PULSE_IS_CONNECTION (connection), FALSE);
+    g_return_val_if_fail (volume != NULL, FALSE);
 
     if (connection->priv->state != PULSE_CONNECTION_CONNECTED)
         return FALSE;
@@ -1038,9 +1043,6 @@ pulse_connection_set_source_output_volume (PulseConnection  *connection,
                                               NULL, NULL);
 
     return process_pulse_operation (connection, op);
-#else
-    return FALSE;
-#endif
 }
 
 gboolean
@@ -1166,6 +1168,7 @@ pulse_connection_write_ext_stream (PulseConnection                  *connection,
     pa_operation *op;
 
     g_return_val_if_fail (PULSE_IS_CONNECTION (connection), FALSE);
+    g_return_val_if_fail (info != NULL, FALSE);
 
     if (connection->priv->state != PULSE_CONNECTION_CONNECTED)
         return FALSE;
@@ -1187,6 +1190,7 @@ pulse_connection_delete_ext_stream (PulseConnection *connection,
     gchar       **names;
 
     g_return_val_if_fail (PULSE_IS_CONNECTION (connection), FALSE);
+    g_return_val_if_fail (name != NULL, FALSE);
 
     if (connection->priv->state != PULSE_CONNECTION_CONNECTED)
         return FALSE;
